.. image:: https://vspec.readthedocs.io/en/latest/_images/vspec_logo.png
    :width: 400
    :alt: VSPEC Logo
    :align: center

|Documentation Status| |MIT license|

.. |Documentation Status| image:: https://readthedocs.org/projects/vspec/badge/?version=latest
   :target: http://vspec.readthedocs.io/?badge=latest

.. |MIT license| image:: https://img.shields.io/badge/License-MIT-blue.svg
   :target: https://lbesson.mit-license.org/

.. image:: https://coveralls.io/repos/github/VSPEC-collab/VSPEC/badge.svg?branch=main
   :target: https://coveralls.io/github/VSPEC-collab/VSPEC?branch=main



VSPEC: Variable Star PhasE Curve
================================

VSPEC combines NASA's Planetary Spectrum Generator (PSG) with a custom stellar model
to produce phase curves of variable host + planet systems.

Documentation
-------------

VSPEC's documentation is hosted on readthedocs `here <https://vspec.readthedocs.io/en/latest/index.html>`_.
There you can find a description of the API as well as numerous examples.

How to Cite
-----------

A JOSS paper describing VSPEC is in the works.

Authors
-------

VSPEC was written by CRESST II post-baccs Cameron Kelahan and Ted Johnson with support
from many others. See Authors.md for more info.

VSPEC is currently maintained by Ted Johnson

Questions
---------

To report bugs, ask questions, and request features please use the Issues page or email the authors.

Contributing
------------

Please reach out if you are interested in contributing to this project!